(* Types prdfinis                                                     *)


(* type reprsentant les expressions arithmtiques du langage		*)
type expr =
  Plus of expr * expr			(* addition			*)
| Moins of expr * expr			(* soustraction			*)
| Div of expr * expr			(* division			*)
| Mult of expr* expr			(* multiplication		*)
| Var of string				(* variable			*)
| Const of float			(* constante relle		*)
| Cosinus of expr			(* cosinus			*)
| Sinus of expr				(* sinus			*)
| Tangente of expr;;			(* tangente			*)


(* type reprsentant les expressions boolennes du langage		*)
type test =
  Equal of expr * expr			(* galit			*)
| InfEq of expr * expr			(* infrieur ou gal		*)
| And   of test * test			(* et logique			*)
| Or    of test * test			(* ou logique			*)
| Not   of test;;			(* ngation logique		*)


(* type reprsentant les mots-cls et les identificateurs du langage	*)
type mot =
  IF					(* mot-cl			*)
| THEN					(* mot-cl			*)
| ELSE					(* mot-cl			*)
| BEGIN					(* mot-cl			*)
| END					(* mot-cl			*)
| REPEAT				(* mot-cl			*)
| DEF					(* mot-cl			*)
| CALL					(* mot-cl			*)
| ROTATE				(* mot-cl			*)
| MOVE					(* mot-cl			*)
| JUMP					(* mot-cl			*)
| COLOR                                 (* mot-cl                      *)
| FILL                                  (* mot-cl                      *)
| NOFILL                                (* mot-cl                      *)
| IDENT of string;;			(* identificateur		*)


(* type des fichiers utiliss en lecture				*)
type flux_lecture;;


(************************************************************************)
(* Exceptions et fonctions de lecture prdfinies                       *)


(* exception levee par les fonctions de lecture ci-dessous		*)
(* lorsqu'on rencontre une erreur de syntaxe.				*)
exception ErreurLecture of string;;


(* ouverture d'un fichier en lecture a partir de son nom.		*)
value ouvre_fichier : string -> flux_lecture;;


(* fermeture d'un fichier						*)
value ferme_fichier : flux_lecture -> unit;;


(* information sur la position courante dans le fichier			*)
(* sous la forme d'une chaine de caracteres. Utile au debuggage.	*)
value position_courante : flux_lecture -> string;;


(* lecture d'une expression booleenne.					*)
value lit_condition : flux_lecture -> test;;


(* lecture d'une liste de variables entre parentheses,			*)
(* separees par des virgules.						*)
(* Utile pour lire les parametres formels d'une procedure.		*)
value lit_parametres : flux_lecture -> string list;;


(* lecture d'une liste d'expressions entre parentheses,			*)
(* separees par des virgules.						*)
(* Utile pour lire les parametres reels d'une procedure appelee.	*)
value lit_arguments : flux_lecture -> expr list;;


(* lecture d'un mot-cle ou d'un identificateur (variable)		*)
value lit_mot_cle : flux_lecture -> mot;;


(************************************************************************)
(* Exceptions et fonctions graphiques prdfinies                       *)


(* changement de couleur du mode graphique. Les trois arguments sont    *)
(* convertis en entier et utiliss modulo 256. Ils correspondent donc   *)
(*  trois octets codant respectivement la proportion de rouge, de vert *)
(* et de bleu dans la nouvelle couleur du curseur.                      *)
value fcolor : float -> float -> float -> unit;;


(* dplacement sans trace  la position (x, y). Les deux arguments sont *)
(* convertis  l'entier le plus proche. (x, y) devient la prochaine     *)
(* position courante.                                                   *)
value fmoveto : float * float -> unit;;


(* dplacement avec trace  la position (x, y). Les deux arguments sont *)
(* convertis  l'entier le plus proche. Une ligne est trace entre la   *)
(* position courante et (x, y), prochaine position courante.            *)
value flineto : float * float -> unit;;


(* ftriangle (ox, oy) (x, y) (x', y') : trace un triangle plein entre   *)
(* les points (ox, oy), (x, y) et (x', y'). Vrifie qu'on a bien        *)
(* la condition (ox, oy) <> (x, y) (le curseur a boug).                *)
(* (x', y') devient la prochaine position courante. Utile en mode FILL  *)                                       
value ftriangle :  float * float ->  float * float ->  float * float ->  unit;;

